@@ -753,7 +753,7 @@ class LiticService:
         if not self.last_jobid:
             raise LiticOutputError("No job has been done. No results available.")
 
-        if self.get_available_scalars() < 1 :
+        if len(self.get_available_scalars()) < 1 :
             raise LiticOutputError("No scalar results available.")
 
         download_filename = "scalars.csv"
